==================
vac_aligner
==================


.. image:: https://img.shields.io/pypi/v/vac_aligner.svg
        :target: https://pypi.python.org/pypi/vac_aligner

.. image:: https://img.shields.io/travis/Ara-Yeroyan/vac_aligner.svg
        :target: https://travis-ci.com/Ara-Yeroyan/vac_aligner

.. image:: https://readthedocs.org/projects/vac_aligner/badge/?version=latest
        :target: https://vac_aligner.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Automated Clustering and Annomally Detection


* Free software: Apache Software License 2.0
* Documentation: https://vac_aligner.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
